@@ -1,5 +1,7 @@
 from django.contrib.auth.tokens import PasswordResetTokenGenerator
-from django.utils import six
+
+# from django.utils import six
+import six
 
 
 class TokenGenerator(PasswordResetTokenGenerator):
@@ -7,8 +9,9 @@ class TokenGenerator(PasswordResetTokenGenerator):
 
     def _make_hash_value(self, user, timestamp):
         return (
-            six.text_type(user.pk) + six.text_type(timestamp) +
-            six.text_type(user.is_active)
+            six.text_type(user.pk)
+            + six.text_type(timestamp)
+            + six.text_type(user.is_active)
         )
 
 
