@@ -95,7 +95,11 @@ def landing_page(request):
 
 def check_sub_domain(request):
     if request.method == "GET":
-        return render(request, "check_subdomain.html", {})
+        try:
+            if request.company:
+                return redirect("common:login")
+        except:
+            return render(request, "check_subdomain.html", {})
     if request.method == "POST":
         sub_domain = request.POST.get("sub_domain", "")
         company = Company.objects.filter(sub_domain=sub_domain).first()
@@ -217,88 +221,88 @@ class ProfileView(LoginRequiredMixin, TemplateView):
         return context
 
 
-class LoginView(TemplateView):
-    template_name = "login.html"
+# class LoginView(TemplateView):
+#     template_name = "login.html"
 
-    def get_context_data(self, **kwargs):
-        context = super(LoginView, self).get_context_data(**kwargs)
-        context["ENABLE_GOOGLE_LOGIN"] = settings.ENABLE_GOOGLE_LOGIN
-        context["GP_CLIENT_SECRET"] = settings.GP_CLIENT_SECRET
-        context["GP_CLIENT_ID"] = settings.GP_CLIENT_ID
-        return context
+#     def get_context_data(self, **kwargs):
+#         context = super(LoginView, self).get_context_data(**kwargs)
+#         context["ENABLE_GOOGLE_LOGIN"] = settings.ENABLE_GOOGLE_LOGIN
+#         context["GP_CLIENT_SECRET"] = settings.GP_CLIENT_SECRET
+#         context["GP_CLIENT_ID"] = settings.GP_CLIENT_ID
+#         return context
 
-    def dispatch(self, request, *args, **kwargs):
-        if request.user.is_authenticated:
-            return redirect("common:dashboard")
-        return super(LoginView, self).dispatch(request, *args, **kwargs)
+#     def dispatch(self, request, *args, **kwargs):
+#         if request.user.is_authenticated:
+#             return redirect("common:dashboard")
+#         return super(LoginView, self).dispatch(request, *args, **kwargs)
 
-    def post(self, request, *args, **kwargs):
-        form = LoginForm(request.POST, request=request)
-        if form.is_valid():
+#     def post(self, request, *args, **kwargs):
+#         form = LoginForm(request.POST, request=request)
+#         if form.is_valid():
 
-            user = User.objects.filter(email=request.POST.get("email")).first()
-            # user = authenticate(username=request.POST.get('email'), password=request.POST.get('password'))
-            if user is not None:
-                if user.is_active:
-                    user = authenticate(
-                        username=request.POST.get("email"),
-                        password=request.POST.get("password"),
-                    )
-                    if user is not None:
-                        login(request, user)
-                        if user.has_sales_access:
-                            return redirect("common:dashboard")
-                        elif user.has_marketing_access:
-                            return redirect("marketing:dashboard")
-                        else:
-                            return redirect("common:dashboard")
-                    return render(
-                        request,
-                        "login.html",
-                        {
-                            "ENABLE_GOOGLE_LOGIN": settings.ENABLE_GOOGLE_LOGIN,
-                            "GP_CLIENT_SECRET": settings.GP_CLIENT_SECRET,
-                            "GP_CLIENT_ID": settings.GP_CLIENT_ID,
-                            "error": True,
-                            "message": "Your username and password didn't match. \
-                        Please try again.",
-                        },
-                    )
-                return render(
-                    request,
-                    "login.html",
-                    {
-                        "ENABLE_GOOGLE_LOGIN": settings.ENABLE_GOOGLE_LOGIN,
-                        "GP_CLIENT_SECRET": settings.GP_CLIENT_SECRET,
-                        "GP_CLIENT_ID": settings.GP_CLIENT_ID,
-                        "error": True,
-                        "message": "Your Account is inactive. Please Contact Administrator",
-                    },
-                )
-            return render(
-                request,
-                "login.html",
-                {
-                    "ENABLE_GOOGLE_LOGIN": settings.ENABLE_GOOGLE_LOGIN,
-                    "GP_CLIENT_SECRET": settings.GP_CLIENT_SECRET,
-                    "GP_CLIENT_ID": settings.GP_CLIENT_ID,
-                    "error": True,
-                    "message": "Your Account is not Found. Please Contact Administrator",
-                },
-            )
+#             user = User.objects.filter(email=request.POST.get("email")).first()
+#             # user = authenticate(username=request.POST.get('email'), password=request.POST.get('password'))
+#             if user is not None:
+#                 if user.is_active:
+#                     user = authenticate(
+#                         username=request.POST.get("email"),
+#                         password=request.POST.get("password"),
+#                     )
+#                     if user is not None:
+#                         login(request, user)
+#                         if user.has_sales_access:
+#                             return redirect("common:dashboard")
+#                         elif user.has_marketing_access:
+#                             return redirect("marketing:dashboard")
+#                         else:
+#                             return redirect("common:dashboard")
+#                     return render(
+#                         request,
+#                         "login.html",
+#                         {
+#                             "ENABLE_GOOGLE_LOGIN": settings.ENABLE_GOOGLE_LOGIN,
+#                             "GP_CLIENT_SECRET": settings.GP_CLIENT_SECRET,
+#                             "GP_CLIENT_ID": settings.GP_CLIENT_ID,
+#                             "error": True,
+#                             "message": "Your username and password didn't match. \
+#                         Please try again.",
+#                         },
+#                     )
+#                 return render(
+#                     request,
+#                     "login.html",
+#                     {
+#                         "ENABLE_GOOGLE_LOGIN": settings.ENABLE_GOOGLE_LOGIN,
+#                         "GP_CLIENT_SECRET": settings.GP_CLIENT_SECRET,
+#                         "GP_CLIENT_ID": settings.GP_CLIENT_ID,
+#                         "error": True,
+#                         "message": "Your Account is inactive. Please Contact Administrator",
+#                     },
+#                 )
+#             return render(
+#                 request,
+#                 "login.html",
+#                 {
+#                     "ENABLE_GOOGLE_LOGIN": settings.ENABLE_GOOGLE_LOGIN,
+#                     "GP_CLIENT_SECRET": settings.GP_CLIENT_SECRET,
+#                     "GP_CLIENT_ID": settings.GP_CLIENT_ID,
+#                     "error": True,
+#                     "message": "Your Account is not Found. Please Contact Administrator",
+#                 },
+#             )
 
-        return render(
-            request,
-            "login.html",
-            {
-                "ENABLE_GOOGLE_LOGIN": settings.ENABLE_GOOGLE_LOGIN,
-                "GP_CLIENT_SECRET": settings.GP_CLIENT_SECRET,
-                "GP_CLIENT_ID": settings.GP_CLIENT_ID,
-                # "error": True,
-                # "message": "Your username and password didn't match. Please try again."
-                "form": form,
-            },
-        )
+#         return render(
+#             request,
+#             "login.html",
+#             {
+#                 "ENABLE_GOOGLE_LOGIN": settings.ENABLE_GOOGLE_LOGIN,
+#                 "GP_CLIENT_SECRET": settings.GP_CLIENT_SECRET,
+#                 "GP_CLIENT_ID": settings.GP_CLIENT_ID,
+#                 # "error": True,
+#                 # "message": "Your username and password didn't match. Please try again."
+#                 "form": form,
+#             },
+#         )
 
 
 class ForgotPasswordView(TemplateView):
@@ -389,19 +393,21 @@ class CompanyLoginView(CreateView):
         if form.is_valid():
             email = form.cleaned_data.get("email", "")
             password = form.cleaned_data.get("password", "")
-            company = get_object_or_404(Company, pk=form.data.get("company", ""))
-            if company:
-                user = User.objects.filter(email=email, company=company).first()
+            # company = get_object_or_404(Company, pk=form.data.get("company", ""))
+            if request.company:
+                user = User.objects.filter(email=email, company=request.company).first()
                 if user is not None:
                     if user.is_active:
-                        user = authenticate(email=email, password=password,)
+                        user = authenticate(
+                            email=email, password=password, company=request.company
+                        )
                         if user is not None:
                             login(request, user)
                             request.session["company"] = (
                                 user.company.id if user.company else None
                             )
                             if user.has_sales_access:
-                                return redirect("common:dashboard")
+                                return redirect(reverse("common:dashboard"))
                             elif user.has_marketing_access:
                                 return redirect("marketing:dashboard")
                             else:
