@@ -3,17 +3,17 @@ import os
 from celery import Celery
 
 # set the default Django settings module for the 'celery' program.
-os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.settings')
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "crm.settings")
 # os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.dev_settings')
 # os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.server_settings')
 
-app = Celery('crm')
+app = Celery("crm")
 
 # Using a string here means the worker don't have to serialize
 # the configuration object to child processes.
 # - namespace='CELERY' means all celery-related configuration keys
 #   should have a `CELERY_` prefix.
-app.config_from_object('django.conf:settings', namespace='CELERY')
+app.config_from_object("django.conf:settings", namespace="CELERY")
 
 # Load task modules from all registered Django app configs.
 app.autodiscover_tasks()
