@@ -6,11 +6,13 @@ from opportunity.tests import OpportunityModel
 
 
 class TestCeleryTasks(OpportunityModel, TestCase):
-
-    @override_settings(CELERY_EAGER_PROPAGATES_EXCEPTIONS=True,
-                       CELERY_ALWAYS_EAGER=True,
-                       BROKER_BACKEND='memory')
+    @override_settings(
+        CELERY_EAGER_PROPAGATES_EXCEPTIONS=True,
+        CELERY_ALWAYS_EAGER=True,
+        BROKER_BACKEND="memory",
+    )
     def test_celery_tasks(self):
         task = send_email_to_assigned_user.apply(
-            ([self.user.id, self.user1.id, ], self.opportunity.id,),)
-        self.assertEqual('SUCCESS', task.state)
+            ([self.user.id, self.user1.id,], self.opportunity.id,),
+        )
+        self.assertEqual("SUCCESS", task.state)
